- This release introduces a new :ref:`callback API <callbacks_user>` to invoke callbacks
  during the fitting of estimators that support them. It comes with two built-in
  callbacks:

  - :class:`sklearn.callback.ProgressBar`, to display progress bars.
  - :class:`sklearn.callback.ScoringMonitor`, to compute and log a scoring metric at the
    end of each iteration.

  The following estimators support callbacks:

  - :class:`~sklearn.linear_model.LogisticRegression` (only with ``solver="lbfgs"``).
  - :class:`~sklearn.model_selection.GridSearchCV`
  - :class:`~sklearn.model_selection.HalvingGridSearchCV`
  - :class:`~sklearn.model_selection.HalvingRandomSearchCV`
  - :class:`~sklearn.model_selection.RandomizedSearchCV`
  - :class:`~sklearn.pipeline.Pipeline`
  - :class:`~sklearn.preprocessing.StandardScaler`

  It also provides a public API to implement callback support in custom estimators or
  or to implement custom callbacks, see the :ref:`developer's guide <callbacks>`.

  This API is experimental for now and may change without the usual deprecation cycle.

  By :user:`Jérémie du Boisberranger <jeremiedbb>`, :user:`François Paugam
  <FrancoisPgm>` and :user:`Stefanie Senger <StefanieSenger>`.
